##  Step 1: Create an Application for SSO
Follow these steps:
  1. In the Okta admin dashboard, in the Applications section, click Create App Integration.
  2. In the overlay that appears, select SAML 2.0 as the sign-in method.
![Selecting SAML 2.0 as the Sign-In Method for an SSO Application in Okta](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27552b377a441014ba1de54221dbdb60_LowRes.png)
Selecting SAML 2.0 as the Sign-In Method for an SSO Application in Okta
  3. Enter a name for your application, then click Next.
